@@ -115,11 +115,10 @@ static int32_t SDLCALL resampleThread(void *ptr)
 	pauseAudio();
 	unfixSample(s);
 
-	/* Nearest-neighbor resampling (no interpolation).
+	/* Fast nearest-neighbor resampling.
 	**
 	** Could benefit from windowed-sinc interpolation,
-	** but it seems like some people prefer no resampling
-	** interpolation (like FT2).
+	** but it seems like some people prefer it the way it is.
 	*/
 
 	if (newLen > 0)
@@ -131,8 +130,7 @@ static int32_t SDLCALL resampleThread(void *ptr)
 
 			for (uint32_t i = 0; i < newLen; i++)
 			{
-				const uint32_t position = posFrac64 >> 32;
-				dst16[i] = src16[position];
+				dst16[i] = src16[posFrac64 >> 32];
 				posFrac64 += delta64;
 			}
 		}
@@ -143,8 +141,7 @@ static int32_t SDLCALL resampleThread(void *ptr)
 
 			for (uint32_t i = 0; i < newLen; i++)
 			{
-				const uint32_t position = posFrac64 >> 32;
-				dst8[i] = src8[position];
+				dst8[i] = src8[posFrac64 >> 32];
 				posFrac64 += delta64;
 			}
 		}
@@ -428,8 +425,11 @@ static int32_t SDLCALL createEchoThread(void *ptr)
 	// calculate real number of echoes
 	double dSmp = sample16Bit ? 32768.0 : 128.0;
 	int32_t k = 0;
-	while (k++ < echo_nEcho && dSmp >= 1.0)
+	while (k < echo_nEcho && dSmp >= 1.0)
+	{
 		dSmp *= dVolChange;
+		k++;
+	}
 	int32_t nEchoes = k + 1;
 
 	if (nEchoes < 1)
@@ -1196,9 +1196,9 @@ static int32_t SDLCALL applyVolumeThread(void *ptr)
 	if (len <= 0)
 		goto applyVolumeExit;
 
-	bool mustInterpolate = (dVol_StartVol != dVol_EndVol);
-	const double dVol = dVol_StartVol / 100.0;
-	const double dPosMul = ((dVol_EndVol / 100.0) - dVol) / len;
+	const bool mustInterpolate = (dVol_StartVol != dVol_EndVol);
+	const double dVolDelta = ((dVol_EndVol - dVol_StartVol) / 100.0) / len;
+	double dVol = dVol_StartVol / 100.0;
 
 	pauseAudio();
 	unfixSample(s);
@@ -1209,23 +1209,18 @@ static int32_t SDLCALL applyVolumeThread(void *ptr)
 		{
 			for (int32_t i = 0; i < len; i++)
 			{
-				double dSmp = (int32_t)ptr16[i] * (dVol + (i * dPosMul)); // linear interpolation
-				DROUND(dSmp);
-
-				int32_t smp32 = (int32_t)dSmp;
+				int32_t smp32 = (int32_t)((int32_t)ptr16[i] * dVol);
 				CLAMP16(smp32);
 				ptr16[i] = (int16_t)smp32;
-			}
 
+				dVol += dVolDelta;
+			}
 		}
 		else // no interpolation needed
 		{
 			for (int32_t i = 0; i < len; i++)
 			{
-				double dSmp = (int32_t)ptr16[i] * dVol;
-				DROUND(dSmp);
-
-				int32_t smp32 = (int32_t)dSmp;
+				int32_t smp32 = (int32_t)((int32_t)ptr16[i] * dVol);
 				CLAMP16(smp32);
 				ptr16[i] = (int16_t)smp32;
 			}
@@ -1238,22 +1233,18 @@ static int32_t SDLCALL applyVolumeThread(void *ptr)
 		{
 			for (int32_t i = 0; i < len; i++)
 			{
-				double dSmp = (int32_t)ptr8[i] * (dVol + (i * dPosMul)); // linear interpolation
-				DROUND(dSmp);
-
-				int32_t smp32 = (int32_t)dSmp;
+				int32_t smp32 = (int32_t)((int32_t)ptr8[i] * dVol);
 				CLAMP8(smp32);
 				ptr8[i] = (int8_t)smp32;
+
+				dVol += dVolDelta;
 			}
 		}
 		else // no interpolation needed
 		{
 			for (int32_t i = 0; i < len; i++)
 			{
-				double dSmp = (int32_t)ptr8[i] * dVol;
-				DROUND(dSmp);
-
-				int32_t smp32 = (int32_t)dSmp;
+				int32_t smp32 = (int32_t)((int32_t)ptr8[i] * dVol);
 				CLAMP8(smp32);
 				ptr8[i] = (int8_t)smp32;
 			}
